==> fantacalciobazar_0.3.tar.gz: fantacalciobazar/scambia.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

include("dati/head.php");

include("controlla_pass.php");
if ($pass_errata != "SI") {



if ($num_calciatori_scambiabili == 0) echo "Non si possono fare scambi.<br>";

else {



$num_calciatori_posseduti = 0;
$num_calciatori_effettivi = 0;
$soldi_spesi = 0;
$calciatori_utente = "";
$num_calciatori_posseduti_altro = 0;
$num_calciatori_effettivi_altro = 0;
$soldi_spesi_altro = 0;
$calciatori_altro = "";
$num_calciatori_offerti = 0;
$num_calciatori_richiesti = 0;
$lista_ric = "";
$lista_off = "";
$calciatori = @file("dati/mercato.txt");
$num_calciatori = count($calciatori);

for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
$proprietario = $dati_calciatore[4];

if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
if ($sec_restanti < 0) {
$num_calciatori_effettivi++;
$nomi_calciatori_utente[$num_calciatori_effettivi] = $nome;
$num_calciatori_utente[$num_calciatori_effettivi] = $numero;
$calciatori_utente[$numero] = "SI";
} # fine if ($sec_restanti < 0)
} # fine if ($proprietario == $nome_utente)

if ($proprietario == $altro_utente) {
$soldi_spesi_altro = $soldi_spesi_altro + $dati_calciatore[3];
$num_calciatori_posseduti_altro++;
if ($sec_restanti < 0) { 
$num_calciatori_effettivi_altro++;
$nomi_calciatori_altro[$num_calciatori_effettivi_altro] = $nome;
$num_calciatori_altro[$num_calciatori_effettivi_altro] = $numero;
$calciatori_altro[$numero] = "SI";
} # fine if ($sec_restanti < 0)
} # fine if ($proprietario == $altro_utente)

} # fine for $num1


if ($offri_scambio) {
for ($num1 = 0 ; $num1 < $num_calciatori_scambiabili ; $num1++) {
$calciatore_scambio_utente = "calciatore_scambio_utente$num1";
$calciatore_scambio_utente = $$calciatore_scambio_utente;
if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and $calciatore_scambio_utente != "") {
$scambiare = "NO";
echo "Hai offerto un calciatore non in tuo possesso!<br>";
} # fine if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and...
if ($gia_offerti_utente[$calciatore_scambio_utente] == "SI") {
$scambiare = "NO";
echo "Hai offerto pi volte lo stesso calciatore.<br>";
} # fine if ($gia_offerti_utente[$calciatore_scambio_utente] == "SI")
if ($calciatore_scambio_utente != "") {
if ($num_calciatori_offerti > 0) $lista_off .= ";$calciatore_scambio_utente";
else $lista_off .= "$calciatore_scambio_utente";
$gia_offerti_utente[$calciatore_scambio_utente] = "SI";
$num_calciatori_offerti++;
} # fine if ($calciatore_scambio_utente != "")
$calciatore_scambio_altro = "calciatore_scambio_altro$num1";
$calciatore_scambio_altro = $$calciatore_scambio_altro;
if ($calciatori_altro[$calciatore_scambio_altro] != "SI" and $calciatore_scambio_altro != "") {
$scambiare = "NO";
echo "Hai richiesto un calciatore non posseduto da $altro_utente!<br>";
} # fine if ($calciatori_altro[$calciatore_scambio_altro] != "SI" and...
if ($gia_offerti_altro[$calciatore_scambio_altro] == "SI") {
$scambiare = "NO";
echo "Hai richiesto pi volte lo stesso calciatore.<br>";
} # fine if ($gia_offerti_altro[$calciatore_scambio_altro] == "SI")
if ($calciatore_scambio_altro != "") {
if ($num_calciatori_richiesti > 0) $lista_ric .= ";$calciatore_scambio_altro";
else $lista_ric .= "$calciatore_scambio_altro";
$gia_offerti_altro[$calciatore_scambio_altro] = "SI";
$num_calciatori_richiesti++;
} # fine if ($calciatore_scambio_utente != "")
} # fine for $num1

if ($num_calciatori_offerti == 0) {
$scambiare = "NO";
echo "Non hai offerto nessun calciatore.<br>";
} # fine if ($num_calciatori_offerti == 0)
if ($num_calciatori_richiesti == 0) {
$scambiare = "NO";
echo "Non hai richiesto nessun calciatore.<br>";
} # fine if ($num_calciatori_richiesti == 0)

$num_calciatori_dopo = $num_calciatori_posseduti + $num_calciatori_richiesti - $num_calciatori_offerti;
if ($num_calciatori_dopo > $max_calciatori) {
$scambiare = "NO";
echo "Dopo lo scambio avresti pi di $max_calciatori calciatori.<br>";
} # fine if ($num_calciatori_dopo > $max_calciatori)

if ($nome_utente == $altro_utente) {
$scambiare = "NO";
echo "Hai una doppia personalit?.<br>";
} # fine if ($nome_utente == $altro_utente)

$verifica_num = ereg_replace("[0-9]","",$soldi_scambio_utente);
$verifica_num_altro = ereg_replace("[0-9]","",$soldi_scambio_altro);
if ($verifica_num != "" or $verifica_num_altro != "") {
$scambiare = "NO";
echo "Gli Euro devono essere un numero intero.<br>";
} # fine if ($verifica_num != "")

$surplus = @file("dati/squadra_$nome_utente");
$surplus = $surplus[0];
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($soldi_scambio_utente > $soldi_spendibili) {
$scambiare = "NO";
echo "Hai offerto pi soldi di quelli da te posseduti.<br>";
} # fine if ($soldi_scambio_utente > $soldi_spendibili)
$surplus_altro = @file("dati/squadra_$altro_utente");
$surplus_altro = $surplus_altro[0];
$soldi_spendibili_altro = $soldi_iniziali + $surplus_altro - $soldi_spesi_altro;
if ($soldi_scambio_altro > $soldi_iniziali) {
$scambiare = "NO";
echo "Hai richiesto a $altro_utente pi soldi di quelli iniziali.<br>";
} # fine if ($soldi_scambio_utente > $soldi_spendibili)

if ($scambiare != "NO") {
$lock = fopen("dati/scambi.lock","w+");
flock($lock,2);
$scambi_proposti = @file("dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);
$num_offerte_utente = 0;
$id_scambio = 0;
for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
$dati_scambio = explode(",", $scambi_proposti[$num1]);
if ($num1 == 0 and $dati_scambio[0]) $id_scambio = $dati_scambio[0];
$offerente = $dati_scambio[1];
if ($offerente == $nome_utente) $num_offerte_utente++;
} # fine for $num1
if ($num_offerte_utente >= 12) {
$scambiare = "NO";
echo "Hai gi in corso 12 offerte di scambio.<br>";
} # fine if ($num_offerte_utente >= 12)

# finalmente dopo tutti i controlli inserisco lo scambio
if ($scambiare != "NO") {
$file_scambi = fopen("dati/scambi.txt","w+");
flock($file_scambi,2);
$anno_attuale = date("Y");
$mese_attuale = date("m");
$giorno_attuale = date("d");
$ora_attuale = date("H");
$minuto_attuale = date("i");
$scadenza = date("YmdHi",mktime($ora_attuale+$aspetta_ore,$minuto_attuale+$aspetta_minuti,0,$mese_attuale,$giorno_attuale+$aspetta_giorni,$anno_attuale));
if (!$soldi_scambio_utente) $soldi_scambio_utente = 0;
if (!$soldi_scambio_altro) $soldi_scambio_altro = 0;
$id_scambio++;
$linea = "$id_scambio,$nome_utente,$lista_off,$soldi_scambio_utente,$altro_utente,$lista_ric,$soldi_scambio_altro,$scadenza";
fwrite($file_scambi,"$linea
");
for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
# se lo scambio  scaduto non lo riscrivo
$dati_scambio = explode(",", $scambi_proposti[$num1]);
$tempo_off = $dati_scambio[7];
$tempo_off = ereg_replace("
","",$tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti > 0) fwrite($file_scambi,$scambi_proposti[$num1]);
} # fine for $num1
flock($file_scambi,3);
fclose($file_scambi);
echo "L'offerta di scambio  stata inviata!<br>";
} # fine if ($scambiare != "NO")

flock($lock,3);
fclose($lock);
} # fine if ($scambiare != "NO")

if ($scambiare == "NO") echo "Scambio non permesso.<br>";
} # fine if ($offri_scambio)

else {


echo "<form method=\"post\" action=\"scambia.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"altro_utente\" value=\"$altro_utente\">
<font size=+1>Io (<b>$nome_utente</b>) offro: </font>";
for ($num1 = 0 ; $num1 < $num_calciatori_scambiabili ; $num1++) {
if ($num1 != 0) echo " + ";
echo "<select name=\"calciatore_scambio_utente$num1\">
<option value=\"\" selected>-----</option>";
for ($num2 = 1 ; $num2 <= $num_calciatori_effettivi ; $num2++) {
$nome = $nomi_calciatori_utente[$num2];
$numero = $num_calciatori_utente[$num2];
echo "<option value=\"$numero\">$nome</option>";
} # fine for $num2
echo "</select>";
} # fine for $num1
if ($scambio_con_soldi == "SI") {
echo " + <input type=\"text\" name=\"soldi_scambio_utente\" size=\"8\">
 Euro.";
} # fine if ($scambio_con_soldi == "SI")

echo "<br><font size=+1>per ottenere da <b>$altro_utente</b>: </font>";
for ($num1 = 0 ; $num1 < $num_calciatori_scambiabili ; $num1++) {
if ($num1 != 0) echo " + ";
echo "<select name=\"calciatore_scambio_altro$num1\">
<option value=\"\">-----</option>";
for ($num2 = 1 ; $num2 <= $num_calciatori_effettivi_altro ; $num2++) {
$nome = $nomi_calciatori_altro[$num2];
$numero = $num_calciatori_altro[$num2];
echo "<option value=\"$numero\"";
if ($num1 == 0 and $numero == $num_calciatore) echo " selected";
echo ">$nome</option>";
} # fine for $num2
echo "</select>";
} # fine for $num1
if ($scambio_con_soldi == "SI") {
echo " + <input type=\"text\" name=\"soldi_scambio_altro\" size=\"8\">
 Euro.";
} # fine if ($scambio_con_soldi == "SI")

echo "<center>
<input type=\"submit\" name=\"offri_scambio\" value=\"Offri lo scambio\">
</center></form>";


} # fine else if ($offri_scambio)


} # fine else if ($num_calciatori_scambiabili == 0)


echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("dati/foot.php");
?>

==> fantacalciobazar_0.4.tar.gz: fantacalciobazar/scambia.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



if ($num_calciatori_scambiabili == 0 or $stato_mercato == "C" or $stato_mercato == "S") echo "Non si possono fare scambi.<br>";

else {



$num_calciatori_posseduti = 0;
$num_calciatori_effettivi = 0;
$soldi_spesi = 0;
$calciatori_utente = "";
$num_calciatori_posseduti_altro = 0;
$num_calciatori_effettivi_altro = 0;
$soldi_spesi_altro = 0;
$calciatori_altro = "";
$num_calciatori_offerti = 0;
$num_calciatori_richiesti = 0;
$lista_ric = "";
$lista_off = "";
$calciatori = @file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);

for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
$proprietario = $dati_calciatore[4];

if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
if ($sec_restanti < 0) {
$num_calciatori_effettivi++;
$nomi_calciatori_utente[$num_calciatori_effettivi] = $nome;
$num_calciatori_utente[$num_calciatori_effettivi] = $numero;
$calciatori_utente[$numero] = "SI";
} # fine if ($sec_restanti < 0)
} # fine if ($proprietario == $nome_utente)

if ($proprietario == $altro_utente) {
$soldi_spesi_altro = $soldi_spesi_altro + $dati_calciatore[3];
$num_calciatori_posseduti_altro++;
if ($sec_restanti < 0) { 
$num_calciatori_effettivi_altro++;
$nomi_calciatori_altro[$num_calciatori_effettivi_altro] = $nome;
$num_calciatori_altro[$num_calciatori_effettivi_altro] = $numero;
$calciatori_altro[$numero] = "SI";
} # fine if ($sec_restanti < 0)
} # fine if ($proprietario == $altro_utente)

} # fine for $num1


if ($offri_scambio) {
for ($num1 = 0 ; $num1 < $num_calciatori_scambiabili ; $num1++) {
$calciatore_scambio_utente = "calciatore_scambio_utente$num1";
$calciatore_scambio_utente = $$calciatore_scambio_utente;
if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and $calciatore_scambio_utente != "") {
$scambiare = "NO";
echo "Hai offerto un calciatore non in tuo possesso!<br>";
} # fine if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and...
if ($gia_offerti_utente[$calciatore_scambio_utente] == "SI") {
$scambiare = "NO";
echo "Hai offerto pi volte lo stesso calciatore.<br>";
} # fine if ($gia_offerti_utente[$calciatore_scambio_utente] == "SI")
if ($calciatore_scambio_utente != "") {
if ($num_calciatori_offerti > 0) $lista_off .= ";$calciatore_scambio_utente";
else $lista_off .= "$calciatore_scambio_utente";
$gia_offerti_utente[$calciatore_scambio_utente] = "SI";
$num_calciatori_offerti++;
} # fine if ($calciatore_scambio_utente != "")
$calciatore_scambio_altro = "calciatore_scambio_altro$num1";
$calciatore_scambio_altro = $$calciatore_scambio_altro;
if ($calciatori_altro[$calciatore_scambio_altro] != "SI" and $calciatore_scambio_altro != "") {
$scambiare = "NO";
echo "Hai richiesto un calciatore non posseduto da $altro_utente!<br>";
} # fine if ($calciatori_altro[$calciatore_scambio_altro] != "SI" and...
if ($gia_offerti_altro[$calciatore_scambio_altro] == "SI") {
$scambiare = "NO";
echo "Hai richiesto pi volte lo stesso calciatore.<br>";
} # fine if ($gia_offerti_altro[$calciatore_scambio_altro] == "SI")
if ($calciatore_scambio_altro != "") {
if ($num_calciatori_richiesti > 0) $lista_ric .= ";$calciatore_scambio_altro";
else $lista_ric .= "$calciatore_scambio_altro";
$gia_offerti_altro[$calciatore_scambio_altro] = "SI";
$num_calciatori_richiesti++;
} # fine if ($calciatore_scambio_utente != "")
} # fine for $num1

if ($num_calciatori_offerti == 0) {
$scambiare = "NO";
echo "Non hai offerto nessun calciatore.<br>";
} # fine if ($num_calciatori_offerti == 0)
if ($num_calciatori_richiesti == 0) {
$scambiare = "NO";
echo "Non hai richiesto nessun calciatore.<br>";
} # fine if ($num_calciatori_richiesti == 0)

$num_calciatori_dopo = $num_calciatori_posseduti + $num_calciatori_richiesti - $num_calciatori_offerti;
if ($num_calciatori_dopo > $max_calciatori) {
$scambiare = "NO";
echo "Dopo lo scambio avresti pi di $max_calciatori calciatori.<br>";
} # fine if ($num_calciatori_dopo > $max_calciatori)

if ($nome_utente == $altro_utente) {
$scambiare = "NO";
echo "Hai una doppia personalit?.<br>";
} # fine if ($nome_utente == $altro_utente)

$verifica_num = ereg_replace("[0-9]","",$soldi_scambio_utente);
$verifica_num_altro = ereg_replace("[0-9]","",$soldi_scambio_altro);
if ($verifica_num != "" or $verifica_num_altro != "") {
$scambiare = "NO";
echo "I Fanta-Euro devono essere un numero intero.<br>";
} # fine if ($verifica_num != "")

$surplus = @file("$percorso_cartella_dati/squadra_$nome_utente");
$surplus = $surplus[0];
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($soldi_scambio_utente > $soldi_spendibili) {
$scambiare = "NO";
echo "Hai offerto pi soldi di quelli da te posseduti.<br>";
} # fine if ($soldi_scambio_utente > $soldi_spendibili)
$surplus_altro = @file("$percorso_cartella_dati/squadra_$altro_utente");
$surplus_altro = $surplus_altro[0];
$soldi_spendibili_altro = $soldi_iniziali + $surplus_altro - $soldi_spesi_altro;
if ($soldi_scambio_altro > $soldi_iniziali) {
$scambiare = "NO";
echo "Hai richiesto a $altro_utente pi soldi di quelli iniziali.<br>";
} # fine if ($soldi_scambio_utente > $soldi_spendibili)

if ($scambiare != "NO") {
$lock = fopen("$percorso_cartella_dati/scambi.lock","w+");
flock($lock,2);
$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);
$num_offerte_utente = 0;
$id_scambio = 0;
for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
$dati_scambio = explode(",", $scambi_proposti[$num1]);
if ($num1 == 0 and $dati_scambio[0]) $id_scambio = $dati_scambio[0];
$offerente = $dati_scambio[1];
if ($offerente == $nome_utente) $num_offerte_utente++;
} # fine for $num1
if ($num_offerte_utente >= 12) {
$scambiare = "NO";
echo "Hai gi in corso 12 offerte di scambio.<br>";
} # fine if ($num_offerte_utente >= 12)

# finalmente dopo tutti i controlli inserisco lo scambio
if ($scambiare != "NO") {
$file_scambi = fopen("$percorso_cartella_dati/scambi.txt","w+");
flock($file_scambi,2);
$anno_attuale = date("Y");
$mese_attuale = date("m");
$giorno_attuale = date("d");
$ora_attuale = date("H");
$minuto_attuale = date("i");
$scadenza = date("YmdHi",mktime($ora_attuale+$aspetta_ore,$minuto_attuale+$aspetta_minuti,0,$mese_attuale,$giorno_attuale+$aspetta_giorni,$anno_attuale));
if (!$soldi_scambio_utente) $soldi_scambio_utente = 0;
if (!$soldi_scambio_altro) $soldi_scambio_altro = 0;
$id_scambio++;
$linea = "$id_scambio,$nome_utente,$lista_off,$soldi_scambio_utente,$altro_utente,$lista_ric,$soldi_scambio_altro,$scadenza";
fwrite($file_scambi,"$linea
");
for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
# se lo scambio  scaduto non lo riscrivo
$dati_scambio = explode(",", $scambi_proposti[$num1]);
$tempo_off = $dati_scambio[7];
$tempo_off = ereg_replace("
","",$tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti > 0) fwrite($file_scambi,$scambi_proposti[$num1]);
} # fine for $num1
flock($file_scambi,3);
fclose($file_scambi);
echo "L'offerta di scambio  stata inviata!<br>";
} # fine if ($scambiare != "NO")

flock($lock,3);
fclose($lock);
} # fine if ($scambiare != "NO")

if ($scambiare == "NO") echo "Scambio non permesso.<br>";
} # fine if ($offri_scambio)

else {


echo "<form method=\"post\" action=\"scambia.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"altro_utente\" value=\"$altro_utente\">
<font size=+1>Io (<b>$nome_utente</b>) offro: </font>";
for ($num1 = 0 ; $num1 < $num_calciatori_scambiabili ; $num1++) {
if ($num1 != 0) echo " + ";
echo "<select name=\"calciatore_scambio_utente$num1\">
<option value=\"\" selected>-----</option>";
for ($num2 = 1 ; $num2 <= $num_calciatori_effettivi ; $num2++) {
$nome = $nomi_calciatori_utente[$num2];
$numero = $num_calciatori_utente[$num2];
echo "<option value=\"$numero\">$nome</option>";
} # fine for $num2
echo "</select>";
} # fine for $num1
if ($scambio_con_soldi == "SI") {
echo " + <input type=\"text\" name=\"soldi_scambio_utente\" size=\"8\">
 Fanta-Euro.";
} # fine if ($scambio_con_soldi == "SI")

echo "<br><font size=+1>per ottenere da <b>$altro_utente</b>: </font>";
for ($num1 = 0 ; $num1 < $num_calciatori_scambiabili ; $num1++) {
if ($num1 != 0) echo " + ";
echo "<select name=\"calciatore_scambio_altro$num1\">
<option value=\"\">-----</option>";
for ($num2 = 1 ; $num2 <= $num_calciatori_effettivi_altro ; $num2++) {
$nome = $nomi_calciatori_altro[$num2];
$numero = $num_calciatori_altro[$num2];
echo "<option value=\"$numero\"";
if ($num1 == 0 and $numero == $num_calciatore) echo " selected";
echo ">$nome</option>";
} # fine for $num2
echo "</select>";
} # fine for $num1
if ($scambio_con_soldi == "SI") {
echo " + <input type=\"text\" name=\"soldi_scambio_altro\" size=\"8\">
 Fanta-Euro.";
} # fine if ($scambio_con_soldi == "SI")

echo "<center>
<input type=\"submit\" name=\"offri_scambio\" value=\"Offri lo scambio\">
</center></form>";


} # fine else if ($offri_scambio)


} # fine else if ($num_calciatori_scambiabili == 0)


echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
